@@ -13,6 +13,6 @@ def sub_menu():
     print("\n=== PyPassFusion MENU ===")
     print("[1]. Just want to Save Password?")
     print("[2]. Show user password (not generated one)")
-    print("[3]. Save generated password as a text file")
+    print("[3]. Save Added password as a text file")
     print("[4]. Back to main menu")
     print("=================================")
\ No newline at end of file
